from distutils.core import setup
setup(
    name="pvc_package",
    packages=["pvc_package"],
    version="0.1",
    description="A python version control system",
    author="Charl Kruger, Stephan Kashkarov",
    author_email="charl.kruger@me.com, Kashkarovwork@gmail.com",
    url="https://github.com/Charlkie/Python-Version-Control",
    download_url="https://github.com/Charlkie/Python-Version-Control/archive/0.1.tar.gz",
    keyword=["version control system", "version control"],
    classifiers=[]
)
